@@ -3,14 +3,8 @@ class Embed:
         self.title = title
         self.description = description
 
-    def __repr__(self):
+    def __iter__(self):
         return {
             "title": self.title,
             "description": self.description
-            }
-
-    def __str__(self):
-        return {
-            "title": self.title,
-            "description": self.description
-            }            
\ No newline at end of file
+            }      
\ No newline at end of file
